## Doc types

* [ ] Extract `how to` documents from code.
* [ ] Extract `step by step guide` from code.
* [ ] Extract Developer guide form code.
* [ ] Extract architecture and ERD form code.
* [ ] Extract `FAQ` from code.
* [ ] Extract `API documentation` from code.
* [ ] Extract `Tutorials` from code.
* [ ] Extract `Glossary` from code.
* [ ] Extract `Release notes` from code and git history.
* [ ] Extract `Changelog` from code and git history.
* [ ] Extract `Contributing guide` from code.

## Features

* [ ] Interactive REPL mode to answer questions based on code.
* [ ] Running on CI/CD pipelines and update the docs based on code changes.
* [ ] Support `rokovo.toml`, `.rokovoignore`, `rokovo_context.md`.
* [ ] Index codebase on some global directory to prevent re-indexing and messing user root directory.
